# Algorithms: Spark
These algorithms will be based on or **[Apache Spark](https://spark.apache.org/)** (via AWS Glue/Spark).

- **Spark:** These algorithms are composed of one or many Spark operations or pipelines. 
- **Inputs:** We need to pass in a **DataSource** class handle as input.
- **Outputs:** A modification of the DataSource, this modification may be of the underlying data or may be changes or updates to the meta data (details, quartiles, outliers, etc)
- **Heavy:** These algorithms are considered **heavy** algorithms since they are running using the **Spark** scalable data processing framework.


